@@ -6,6 +6,7 @@
  * Authors: Iain Holmes  <iain@ximian.com>
  */
 
+#include <string.h>
 #include <libgnome/gnome-util.h>
 #include <libgnome/gnome-i18n.h>
 
@@ -144,7 +145,7 @@ size_allocate (GtkWidget *drawing_area,
 	CDDisplayPrivate *priv;
 	PangoContext *context;
 	PangoDirection base_dir;
-	int i, mod;
+	int i;
 	
 	disp = CD_DISPLAY (drawing_area);
 	priv = disp->priv;
@@ -173,7 +174,7 @@ size_request (GtkWidget *widget,
 {
 	CDDisplay *disp;
 	CDDisplayPrivate *priv;
-	int i, height = 0, width = 0, mod;
+	int i, height = 0, width = 0;
 	
 	disp = CD_DISPLAY (widget);
 	priv = disp->priv;
@@ -232,6 +233,7 @@ expose_event (GtkWidget *drawing_area,
 	PangoContext *context;
 	PangoDirection base_dir;
 	GdkRectangle *area;
+	GtkStateType state;
 	int height = 0;
 	int i;
 
@@ -243,6 +245,7 @@ expose_event (GtkWidget *drawing_area,
 	
 	area = &event->area;
 
+	state = GTK_WIDGET_STATE (drawing_area);
 	if (theme->need_resize == TRUE) {
 		cd_display_resize_images (disp, NULL);
 	}
@@ -406,7 +409,7 @@ expose_event (GtkWidget *drawing_area,
 						    base_dir == PANGO_DIRECTION_LTR ? PANGO_ALIGN_LEFT : PANGO_ALIGN_RIGHT);
 
 			gdk_draw_layout_with_colors (drawing_area->window,
-						     drawing_area->style->black_gc,
+						     drawing_area->style->text_gc[state],
 						     X_OFFSET, 
 						     Y_OFFSET + height,
 						     priv->layout[i]->layout,
@@ -454,10 +457,11 @@ static void
 realize (GtkWidget *widget)
 {
 	CDDisplay *disp;
-	GdkColormap *cmap;
 
 	disp = CD_DISPLAY (widget);
 #if 0
+	GdkColormap *cmap;
+
 	cmap = gtk_widget_get_colormap (widget);
 	disp->priv->red.red = 65535;
 	disp->priv->red.green = 0;
@@ -569,17 +573,15 @@ cd_image_new (const char *filename,
 	CDImage *image;
 	char *fullname;
 	
-	image = g_new (CDImage, 1);
+	image = g_new0 (CDImage, 1);
 
 	if (filename[0] != '/') {
 		fullname = gnome_program_locate_file (NULL,
 			   GNOME_FILE_DOMAIN_PIXMAP, filename, TRUE, NULL);
 		if (fullname == NULL) {
-			g_warning ("Error loading %s", filename);
-			g_free (image);
-			return NULL;
+			/* If the elegant way doesn't work, try and brute force it */
+			fullname = g_strconcat(GNOME_ICONDIR, "/", filename, NULL);
 		}
-		
 		image->pixbuf = gdk_pixbuf_new_from_file (fullname, NULL);
 		g_free (fullname);
 	} else {
@@ -616,7 +618,7 @@ init (CDDisplay *disp)
 	for (i = 0; i < CD_DISPLAY_END; i++) {
 		PangoRectangle rect;
 		
-		priv->layout[i] = g_new (GnomeCDText, 1);
+		priv->layout[i] = g_new0 (GnomeCDText, 1);
 		
 		priv->layout[i]->text = g_strdup (_(default_text[i]));
 		priv->layout[i]->length = strlen (_(default_text[i]));
@@ -777,7 +779,7 @@ cd_display_parse_theme (CDDisplay *disp,
 	priv = disp->priv;
 	/* Should probably destroy the old theme here */
 
-	priv->theme = g_new (CDDisplayTheme, 1);
+	priv->theme = g_new0 (CDDisplayTheme, 1);
 	theme = priv->theme;
 
 	theme->need_resize = TRUE;
